@@ -28,6 +28,7 @@
 #include <KgThemeProvider>
 #include <KColorScheme>
 
+static const int MIN_MARGIN = 50;
 static const int GAME_TIME_DELAY = 1000;
 static const int MIN_FILL_PERCENT = 75;
 static const int POINTS_FOR_LIFE = 15;
@@ -93,7 +94,6 @@ void KBounceGameWidget::closeGame()
     {
         m_clock->stop();
         m_board->setPaused( true );
-        unsetCursor();
         m_state = GameOver;
         emit stateChanged( m_state );
         emit gameOver();
@@ -106,7 +106,6 @@ void KBounceGameWidget::closeGame()
 void KBounceGameWidget::newGame()
 {
     closeGame();
-    setCursor( m_vertical ? Qt::SizeVerCursor : Qt::SizeHorCursor );
     m_level = 1;
     m_score = 0;
 
@@ -170,7 +169,6 @@ void KBounceGameWidget::settingsChanged()
         m_renderer.setCustomBackgroundPath(QString());
     }
    
-    renderBackground();
     redraw();
 }
 
@@ -196,7 +194,7 @@ void KBounceGameWidget::levelChanged()
 {
     setGameDifficulty( Kg::difficulty()->currentLevel() );
 
-    if (m_state == Running)
+    if ( m_state == Running || m_state == Paused )
         newGame();
 }
 
@@ -259,33 +257,29 @@ void KBounceGameWidget::tick()
 void KBounceGameWidget::resizeEvent( QResizeEvent* ev )
 {
     kDebug() << "Size" << ev->size();
+
     m_renderer.setBackgroundSize( ev->size() );
-    renderBackground();
-    QSize boardSize( ev->size().width() , ev->size().height() );
-    m_board->resize( boardSize );
-    QRectF rect( 0, 0, m_board->boardBoundingRect().width() + 20, m_board->boardBoundingRect().height() + 20);
+
+    QRectF rect( 0, 0, ev->size().width(), ev->size().height() );
     m_scene.setSceneRect( rect );
-    m_board->setPos( 10, 10 );
-    fitInView( sceneRect(), Qt::KeepAspectRatio );
+
+    QSize boardSize( sceneRect().width()  - MIN_MARGIN,
+                     sceneRect().height() - MIN_MARGIN );
+    m_board->resize( boardSize );
+
+    qreal x = ( sceneRect().width()  - m_board->boundingRect().width() )  / 2;
+    qreal y = ( sceneRect().height() - m_board->boundingRect().height() ) / 2;
+    m_board->setPos( x, y );
 
     redraw();
 }
 
-void KBounceGameWidget::renderBackground()
-{
-    QPalette palette;
-    palette.setBrush( backgroundRole(), m_renderer.renderBackground() );
-    setPalette( palette );
-    setAutoFillBackground( true );
-}
-
-
 void KBounceGameWidget::mouseReleaseEvent( QMouseEvent* event )
 {
     if ( event->button() & Qt::RightButton )
     {
         m_vertical = !m_vertical;
-        setCursor( m_vertical ? Qt::SizeVerCursor : Qt::SizeHorCursor );
+        updateCursor();
     }
 
     if ( event->button() & Qt::LeftButton )
@@ -294,6 +288,10 @@ void KBounceGameWidget::mouseReleaseEvent( QMouseEvent* event )
         {
             m_board->buildWall( mapToScene( event->pos() ), m_vertical );
         }
+        else if ( m_state == Paused )
+        {
+            setPaused( false );
+        }
         else if ( m_state == BetweenLevels )
         {
             newLevel();
@@ -337,10 +335,8 @@ void KBounceGameWidget::newLevel()
     emit timeChanged( m_time );
 
     if (KBounceSettings::useRandomBackgroundPictures())
-    {
         m_renderer.loadNewBackgroundPixmap();
-        renderBackground();
-    }
+
     redraw();
 }  
 
@@ -367,7 +363,9 @@ void KBounceGameWidget::redraw()
 	    m_overlay->show();
 	    break;
     }
-    m_board->redraw();
+
+    updateCursor();
+    m_scene.setBackgroundBrush( m_renderer.renderBackground() );
     update();
 }
 
@@ -411,7 +409,7 @@ void KBounceGameWidget::generateOverlay()
 	    text = i18n( "Welcome to KBounce.\n Click to start a game" );
 	    break;
 	case Paused:
-	    text = i18n( "Paused" );
+	    text = i18n( "Paused\n Click to resume" );
 	    break;
 	case BetweenLevels:
 	    text = i18n( "You have successfully cleared more than %1% of the board\n", MIN_FILL_PERCENT ) +
@@ -451,6 +449,21 @@ void KBounceGameWidget::generateOverlay()
     m_overlay->setPos( pos );
 }
 
+void KBounceGameWidget::focusOutEvent(QFocusEvent *event)
+{
+    if (event->reason() == Qt::ActiveWindowFocusReason)
+    {
+        setPaused( true );
+    }
+}
+
+void KBounceGameWidget::updateCursor()
+{
+    if ( m_state == Running )
+        setCursor( m_vertical ? Qt::SizeVerCursor : Qt::SizeHorCursor );
+    else
+        unsetCursor();
+}
 
 #include "gamewidget.moc"
 
